==> sqlitestudio-3.1.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>GUI rozhranie pre SQLiteStudio, SQLite manažér.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Aktivuje ladiace správy v konzole (dostupné pomocou F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Presmerovať ladiace informácie na štandardný výstup (vynútený ladiaci mód).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>database</source>
        <translation>databáza</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>file</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Database file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <location filename="../main.cpp" line="110"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
</TS>

==> sqlitestudio-3.2.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>GUI rozhranie pre SQLiteStudio, SQLite manažér.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Aktivuje ladiace správy v konzole (dostupné pomocou F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Presmerovať ladiace informácie na štandardný výstup (vynútený ladiaci mód).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>database</source>
        <translation>databáza</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>file</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Database file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Chyba</translation>
    </message>
</context>
</TS>
